==> gromacs_2016.1.orig.tar.gz: gromacs-2016.1/admin/builds/cppcheck.py <==
#
# This file is part of the GROMACS molecular simulation package.
#
# Copyright (c) 2015,2016, by the GROMACS development team, led by
# Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
# and including many others, as listed in the AUTHORS file in the
# top-level source directory and at http://www.gromacs.org.
#
# GROMACS is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public License
# as published by the Free Software Foundation; either version 2.1
# of the License, or (at your option) any later version.
#
# GROMACS is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with GROMACS; if not, see
# http://www.gnu.org/licenses, or write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
#
# If you want to redistribute modifications to GROMACS, please
# consider that scientific software is very special. Version
# control is crucial - bugs must be traceable. We will be happy to
# consider code for inclusion in the official distribution, but
# derived work must not be called official GROMACS. Details are found
# in the README & COPYING files - if they are missing, get the
# official version at http://www.gromacs.org.
#
# To help us fund GROMACS development, we humbly ask that you cite
# the research papers on the package. Check out http://www.gromacs.org.

def do_build(context):
    # TODO: Make the XMLs go directly to the desired folder.
    # xml_dir = context.workspace.get_log_dir(category='cppcheck')
    cmake_opts = {
            'CPPCHECK_EXECUTABLE': context.env.get_cppcheck_command(version='1.72'),
            'CPPCHECK_XML_OUTPUT': 'ON',
            'GMX_SIMD': 'Reference'
        }

    context.run_cmake(cmake_opts)
    context.build_target(target='cppcheck', parallel=True)
    context.process_cppcheck_results('tests/cppcheck-*.xml')

==> gromacs_2018.1.orig.tar.gz: gromacs-2018.1/admin/builds/cppcheck.py <==
#
# This file is part of the GROMACS molecular simulation package.
#
# Copyright (c) 2015,2016,2017, by the GROMACS development team, led by
# Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
# and including many others, as listed in the AUTHORS file in the
# top-level source directory and at http://www.gromacs.org.
#
# GROMACS is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public License
# as published by the Free Software Foundation; either version 2.1
# of the License, or (at your option) any later version.
#
# GROMACS is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with GROMACS; if not, see
# http://www.gnu.org/licenses, or write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
#
# If you want to redistribute modifications to GROMACS, please
# consider that scientific software is very special. Version
# control is crucial - bugs must be traceable. We will be happy to
# consider code for inclusion in the official distribution, but
# derived work must not be called official GROMACS. Details are found
# in the README & COPYING files - if they are missing, get the
# official version at http://www.gromacs.org.
#
# To help us fund GROMACS development, we humbly ask that you cite
# the research papers on the package. Check out http://www.gromacs.org.

def do_build(context):
    # TODO: Make the XMLs go directly to the desired folder.
    # xml_dir = context.workspace.get_log_dir(category='cppcheck')
    cmake_opts = {
            'CPPCHECK_EXECUTABLE': context.env.get_cppcheck_command(version='1.76.1'),
            'CPPCHECK_XML_OUTPUT': 'ON',
            'GMX_SIMD': 'Reference',
            'GMX_USE_RDTSCP': 'OFF'
        }

    context.run_cmake(cmake_opts)
    context.build_target(target='cppcheck', parallel=True)
    context.process_cppcheck_results('tests/cppcheck-*.xml')
